@@ -10,11 +10,13 @@ class scatter:
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker='x',
 					xticker_rotate=0, yticker_rotate=0,
+					x_origin_axis_color=None, y_origin_axis_color=None,
 					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None, 
 					title_font=16, xfont=16, yfont=16, figsize=None, show=True):
 		"""calculates the probability that "token" is found in spam emails
-		
 		:param token: (str)
+		x_origin_axis_color	: 'k' is default black, or 'red'
+		y_origin_axis_color
 		:return: (float) probability "token" is spam based on training emails
 		"""
 		self.title_font = title_font
@@ -23,6 +25,12 @@ class scatter:
 		self.already_called_plot_line = False
 		if figsize is not None: plt.figure(figsize=figsize)
 
+		#plt.grid(True, which='both')
+		if x_origin_axis_color is not None:
+			plt.axvline(x=0, color=x_origin_axis_color)
+		if y_origin_axis_color is not None:
+			plt.axhline(y=0, color=x_origin_axis_color)
+
 		self.plot_scatter(X=X, Y=Y, title=title, xlabel=xlabel, ylabel=ylabel, imgText=imgText, outpath=outpath, 
 					subplot=subplot, xlim=xlim, ylim=ylim, xTextShift=xTextShift, yTextShift=yTextShift,
 					ticker_fontsize=ticker_fontsize, xTextLoc=xTextLoc, yTextLoc=yTextLoc, 
@@ -151,9 +159,17 @@ class scatter:
 
 
 if __name__ == "__main__":
-	textstr = '\n'.join(( r'$\mu=%.2f$' % (0.1, ), r'$\mathrm{median}=%.2f$' % (0, ), r'$\sigma=%.2f$' % (33, )))
-	x = np.linspace(0, 10, 1000)
-	y = np.sin(x)
+##	Example 1	
+#	textstr = '\n'.join(( r'$\mu=%.2f$' % (0.1, ), r'$\mathrm{median}=%.2f$' % (0, ), r'$\sigma=%.2f$' % (33, )))
+#	x = np.linspace(0, 10, 1000)
+#	y = np.sin(x)
+#
+#	lp = lines()
+#	lp.plot_line(x, y, 'Title Here', 'X axis', 'Y axis', imgText=textstr)#, outpath)
 
-	lp = lines()
-	lp.plot_line(x, y, 'Title Here', 'X axis', 'Y axis', imgText=textstr)#, outpath)
+#	Example 2
+	textstr = '\n'.join(( r'$\mu=%.2f$' % (0.1, ), r'$\mathrm{median}=%.2f$' % (0, ), r'$\sigma=%.2f$' % (33, )))
+	x = np.array([0,1,2])
+	y = np.array([1,2,3])
+	textstr = 'X   Y\n-----\n0   1\n1   2\n2   3'
+	pt = scatter(x, y, 'Mysterious Data We Want to Model', 'X axis', 'Y axis', xlim=[-2,6], ylim=[-2,6], imgText=textstr, xTextLoc=-1.5, yTextLoc=5.5)
